# Triagem e Classificação

## Quality Gate

- A demanda foi classificada em uma categoria (tarefa, evento, lista_compras, sugestao, lembrete, informacao)
- A resposta é clara e em português
- Se for tarefa/evento, data e prioridade foram identificadas (ou perguntadas)
- Se for lista de compras, itens foram extraídos da mensagem

## Veto Conditions

- Resposta em outro idioma que não português
- Classificação ausente ou ambígua sem pedido de esclarecimento
